# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'PFAS_SAT.ui',
# licensing of 'PFAS_SAT.ui' applies.
#
# Created: Wed Dec 22 16:30:40 2021
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_PFAS_SAT(object):
    def setupUi(self, PFAS_SAT):
        PFAS_SAT.setObjectName("PFAS_SAT")
        PFAS_SAT.resize(1200, 900)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(PFAS_SAT.sizePolicy().hasHeightForWidth())
        PFAS_SAT.setSizePolicy(sizePolicy)
        PFAS_SAT.setMinimumSize(QtCore.QSize(1200, 900))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/ICONS/PFAS_SAT_1.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        PFAS_SAT.setWindowIcon(icon)
        PFAS_SAT.setIconSize(QtCore.QSize(48, 24))
        self.centralwidget = QtWidgets.QWidget(PFAS_SAT)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.PFAS_SAT_1 = QtWidgets.QTabWidget(self.centralwidget)
        self.PFAS_SAT_1.setEnabled(True)
        self.PFAS_SAT_1.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        self.PFAS_SAT_1.setFont(font)
        self.PFAS_SAT_1.setObjectName("PFAS_SAT_1")
        self.Start_tab = QtWidgets.QWidget()
        self.Start_tab.setObjectName("Start_tab")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.Start_tab)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.Start_new_project = QtWidgets.QPushButton(self.Start_tab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setUnderline(False)
        font.setBold(True)
        self.Start_new_project.setFont(font)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/ICONS/Next.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.Start_new_project.setIcon(icon1)
        self.Start_new_project.setObjectName("Start_new_project")
        self.gridLayout_2.addWidget(self.Start_new_project, 1, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 1, 0, 1, 1)
        self.textBrowser = QtWidgets.QTextBrowser(self.Start_tab)
        self.textBrowser.setOpenExternalLinks(True)
        self.textBrowser.setOpenLinks(True)
        self.textBrowser.setObjectName("textBrowser")
        self.gridLayout_2.addWidget(self.textBrowser, 0, 0, 1, 2)
        self.PFAS_SAT_1.addTab(self.Start_tab, "")
        self.WM_tab = QtWidgets.QWidget()
        self.WM_tab.setObjectName("WM_tab")
        self.gridLayout_24 = QtWidgets.QGridLayout(self.WM_tab)
        self.gridLayout_24.setObjectName("gridLayout_24")
        self.groupBox_11 = QtWidgets.QGroupBox(self.WM_tab)
        self.groupBox_11.setObjectName("groupBox_11")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.groupBox_11)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.WM_DefData = QtWidgets.QRadioButton(self.groupBox_11)
        self.WM_DefData.setObjectName("WM_DefData")
        self.horizontalLayout_4.addWidget(self.WM_DefData)
        self.WM_UserData = QtWidgets.QRadioButton(self.groupBox_11)
        self.WM_UserData.setObjectName("WM_UserData")
        self.horizontalLayout_4.addWidget(self.WM_UserData)
        self.WM_browse = QtWidgets.QToolButton(self.groupBox_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.WM_browse.sizePolicy().hasHeightForWidth())
        self.WM_browse.setSizePolicy(sizePolicy)
        self.WM_browse.setObjectName("WM_browse")
        self.horizontalLayout_4.addWidget(self.WM_browse)
        self.WM_DataPath = QtWidgets.QLineEdit(self.groupBox_11)
        self.WM_DataPath.setMinimumSize(QtCore.QSize(300, 0))
        self.WM_DataPath.setObjectName("WM_DataPath")
        self.horizontalLayout_4.addWidget(self.WM_DataPath)
        self.WM_ImportData = QtWidgets.QPushButton(self.groupBox_11)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/ICONS/Load.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.WM_ImportData.setIcon(icon2)
        self.WM_ImportData.setObjectName("WM_ImportData")
        self.horizontalLayout_4.addWidget(self.WM_ImportData)
        spacerItem1 = QtWidgets.QSpacerItem(381, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.gridLayout_8.addLayout(self.horizontalLayout_4, 0, 0, 1, 1)
        self.gridLayout_24.addWidget(self.groupBox_11, 0, 0, 1, 1)
        self.groupBox_18 = QtWidgets.QGroupBox(self.WM_tab)
        self.groupBox_18.setObjectName("groupBox_18")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.groupBox_18)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.WM_table_prop = QtWidgets.QTableView(self.groupBox_18)
        self.WM_table_prop.setMinimumSize(QtCore.QSize(0, 400))
        self.WM_table_prop.setObjectName("WM_table_prop")
        self.gridLayout_7.addWidget(self.WM_table_prop, 1, 0, 1, 5)
        self.Def_Proc_models = QtWidgets.QPushButton(self.groupBox_18)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Def_Proc_models.sizePolicy().hasHeightForWidth())
        self.Def_Proc_models.setSizePolicy(sizePolicy)
        self.Def_Proc_models.setMinimumSize(QtCore.QSize(0, 0))
        self.Def_Proc_models.setIcon(icon1)
        self.Def_Proc_models.setObjectName("Def_Proc_models")
        self.gridLayout_7.addWidget(self.Def_Proc_models, 2, 4, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(483, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem2, 2, 3, 1, 1)
        self.Update_WM_prop = QtWidgets.QPushButton(self.groupBox_18)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/ICONS/Update.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.Update_WM_prop.setIcon(icon3)
        self.Update_WM_prop.setObjectName("Update_WM_prop")
        self.gridLayout_7.addWidget(self.Update_WM_prop, 2, 1, 1, 1)
        self.Clear_WM_uncert = QtWidgets.QPushButton(self.groupBox_18)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/ICONS/Remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.Clear_WM_uncert.setIcon(icon4)
        self.Clear_WM_uncert.setObjectName("Clear_WM_uncert")
        self.gridLayout_7.addWidget(self.Clear_WM_uncert, 2, 0, 1, 1)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_2 = QtWidgets.QLabel(self.groupBox_18)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_5.addWidget(self.label_2)
        self.WM_Combo = QtWidgets.QComboBox(self.groupBox_18)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.WM_Combo.sizePolicy().hasHeightForWidth())
        self.WM_Combo.setSizePolicy(sizePolicy)
        self.WM_Combo.setMinimumSize(QtCore.QSize(300, 0))
        self.WM_Combo.setObjectName("WM_Combo")
        self.horizontalLayout_5.addWidget(self.WM_Combo)
        self.WM_help = QtWidgets.QPushButton(self.groupBox_18)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.WM_help.sizePolicy().hasHeightForWidth())
        self.WM_help.setSizePolicy(sizePolicy)
        self.WM_help.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/ICONS/Help.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.WM_help.setIcon(icon5)
        self.WM_help.setIconSize(QtCore.QSize(24, 24))
        self.WM_help.setObjectName("WM_help")
        self.horizontalLayout_5.addWidget(self.WM_help)
        self.WM_Show_Uncertainty = QtWidgets.QCheckBox(self.groupBox_18)
        self.WM_Show_Uncertainty.setObjectName("WM_Show_Uncertainty")
        self.horizontalLayout_5.addWidget(self.WM_Show_Uncertainty)
        self.WM_UncertaintyHelp = QtWidgets.QPushButton(self.groupBox_18)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.WM_UncertaintyHelp.sizePolicy().hasHeightForWidth())
        self.WM_UncertaintyHelp.setSizePolicy(sizePolicy)
        self.WM_UncertaintyHelp.setIcon(icon5)
        self.WM_UncertaintyHelp.setIconSize(QtCore.QSize(24, 24))
        self.WM_UncertaintyHelp.setObjectName("WM_UncertaintyHelp")
        self.horizontalLayout_5.addWidget(self.WM_UncertaintyHelp)
        spacerItem3 = QtWidgets.QSpacerItem(150, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem3)
        self.gridLayout_7.addLayout(self.horizontalLayout_5, 0, 0, 1, 5)
        self.WM_ExportData = QtWidgets.QPushButton(self.groupBox_18)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/ICONS/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.WM_ExportData.setIcon(icon6)
        self.WM_ExportData.setObjectName("WM_ExportData")
        self.gridLayout_7.addWidget(self.WM_ExportData, 2, 2, 1, 1)
        self.gridLayout_24.addWidget(self.groupBox_18, 1, 0, 1, 1)
        self.PFAS_SAT_1.addTab(self.WM_tab, "")
        self.PM_tab = QtWidgets.QWidget()
        self.PM_tab.setEnabled(True)
        self.PM_tab.setObjectName("PM_tab")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.PM_tab)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.frame = QtWidgets.QFrame(self.PM_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.frame)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setObjectName("label")
        self.horizontalLayout_11.addWidget(self.label)
        self.ProcModel_Combo = QtWidgets.QComboBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ProcModel_Combo.sizePolicy().hasHeightForWidth())
        self.ProcModel_Combo.setSizePolicy(sizePolicy)
        self.ProcModel_Combo.setMinimumSize(QtCore.QSize(300, 0))
        self.ProcModel_Combo.setObjectName("ProcModel_Combo")
        self.horizontalLayout_11.addWidget(self.ProcModel_Combo)
        self.PM_Help = QtWidgets.QPushButton(self.frame)
        self.PM_Help.setText("")
        self.PM_Help.setIcon(icon5)
        self.PM_Help.setIconSize(QtCore.QSize(24, 24))
        self.PM_Help.setObjectName("PM_Help")
        self.horizontalLayout_11.addWidget(self.PM_Help)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_11.addItem(spacerItem4)
        self.gridLayout_10.addWidget(self.frame, 0, 0, 1, 2)
        self.groupBox_19 = QtWidgets.QGroupBox(self.PM_tab)
        self.groupBox_19.setObjectName("groupBox_19")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_19)
        self.gridLayout.setObjectName("gridLayout")
        self.ProcModel_def_input = QtWidgets.QRadioButton(self.groupBox_19)
        self.ProcModel_def_input.setObjectName("ProcModel_def_input")
        self.gridLayout.addWidget(self.ProcModel_def_input, 0, 0, 1, 1)
        self.ProcModel_user_input = QtWidgets.QRadioButton(self.groupBox_19)
        self.ProcModel_user_input.setObjectName("ProcModel_user_input")
        self.gridLayout.addWidget(self.ProcModel_user_input, 0, 1, 1, 1)
        self.ProcModel_Brow_Input = QtWidgets.QToolButton(self.groupBox_19)
        self.ProcModel_Brow_Input.setObjectName("ProcModel_Brow_Input")
        self.gridLayout.addWidget(self.ProcModel_Brow_Input, 0, 2, 1, 1)
        self.ProcModel_Input_path = QtWidgets.QLineEdit(self.groupBox_19)
        self.ProcModel_Input_path.setObjectName("ProcModel_Input_path")
        self.gridLayout.addWidget(self.ProcModel_Input_path, 0, 3, 1, 1)
        self.gridLayout_10.addWidget(self.groupBox_19, 1, 0, 1, 2)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_10.addItem(spacerItem5, 1, 2, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.PM_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox_3 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.ContWater = QtWidgets.QCheckBox(self.groupBox_3)
        self.ContWater.setObjectName("ContWater")
        self.verticalLayout_11.addWidget(self.ContWater)
        self.ContSoil = QtWidgets.QCheckBox(self.groupBox_3)
        self.ContSoil.setObjectName("ContSoil")
        self.verticalLayout_11.addWidget(self.ContSoil)
        self.verticalLayout.addWidget(self.groupBox_3)
        self.groupBox_5 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.groupBox_5)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.ContactWater = QtWidgets.QCheckBox(self.groupBox_5)
        self.ContactWater.setObjectName("ContactWater")
        self.verticalLayout_13.addWidget(self.ContactWater)
        self.LFLeach = QtWidgets.QCheckBox(self.groupBox_5)
        self.LFLeach.setObjectName("LFLeach")
        self.verticalLayout_13.addWidget(self.LFLeach)
        self.WWTEffluent = QtWidgets.QCheckBox(self.groupBox_5)
        self.WWTEffluent.setObjectName("WWTEffluent")
        self.verticalLayout_13.addWidget(self.WWTEffluent)
        self.WWTSol = QtWidgets.QCheckBox(self.groupBox_5)
        self.WWTSol.setObjectName("WWTSol")
        self.verticalLayout_13.addWidget(self.WWTSol)
        self.RawWWTSol = QtWidgets.QCheckBox(self.groupBox_5)
        self.RawWWTSol.setObjectName("RawWWTSol")
        self.verticalLayout_13.addWidget(self.RawWWTSol)
        self.DewWWTSol = QtWidgets.QCheckBox(self.groupBox_5)
        self.DewWWTSol.setObjectName("DewWWTSol")
        self.verticalLayout_13.addWidget(self.DewWWTSol)
        self.DryWWTSol = QtWidgets.QCheckBox(self.groupBox_5)
        self.DryWWTSol.setObjectName("DryWWTSol")
        self.verticalLayout_13.addWidget(self.DryWWTSol)
        self.ROC = QtWidgets.QCheckBox(self.groupBox_5)
        self.ROC.setObjectName("ROC")
        self.verticalLayout_13.addWidget(self.ROC)
        self.SGAC = QtWidgets.QCheckBox(self.groupBox_5)
        self.SGAC.setObjectName("SGAC")
        self.verticalLayout_13.addWidget(self.SGAC)
        self.SIER = QtWidgets.QCheckBox(self.groupBox_5)
        self.SIER.setObjectName("SIER")
        self.verticalLayout_13.addWidget(self.SIER)
        self.verticalLayout.addWidget(self.groupBox_5)
        self.groupBox_15 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_15.setObjectName("groupBox_15")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.groupBox_15)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.StabSoil = QtWidgets.QCheckBox(self.groupBox_15)
        self.StabSoil.setObjectName("StabSoil")
        self.verticalLayout_14.addWidget(self.StabSoil)
        self.Solidi_Waste = QtWidgets.QCheckBox(self.groupBox_15)
        self.Solidi_Waste.setObjectName("Solidi_Waste")
        self.verticalLayout_14.addWidget(self.Solidi_Waste)
        self.AFFF_1 = QtWidgets.QCheckBox(self.groupBox_15)
        self.AFFF_1.setObjectName("AFFF_1")
        self.verticalLayout_14.addWidget(self.AFFF_1)
        self.AFFF_2 = QtWidgets.QCheckBox(self.groupBox_15)
        self.AFFF_2.setObjectName("AFFF_2")
        self.verticalLayout_14.addWidget(self.AFFF_2)
        self.verticalLayout.addWidget(self.groupBox_15)
        self.gridLayout_6.addLayout(self.verticalLayout, 0, 2, 1, 1)
        self.verticalLayout_18 = QtWidgets.QVBoxLayout()
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.groupBox_4 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_4.setObjectName("groupBox_4")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.MSW = QtWidgets.QCheckBox(self.groupBox_4)
        self.MSW.setObjectName("MSW")
        self.verticalLayout_12.addWidget(self.MSW)
        self.C_D_Waste = QtWidgets.QCheckBox(self.groupBox_4)
        self.C_D_Waste.setObjectName("C_D_Waste")
        self.verticalLayout_12.addWidget(self.C_D_Waste)
        self.Med_Waste = QtWidgets.QCheckBox(self.groupBox_4)
        self.Med_Waste.setObjectName("Med_Waste")
        self.verticalLayout_12.addWidget(self.Med_Waste)
        self.MOSP = QtWidgets.QCheckBox(self.groupBox_4)
        self.MOSP.setObjectName("MOSP")
        self.verticalLayout_12.addWidget(self.MOSP)
        self.verticalLayout_18.addWidget(self.groupBox_4)
        self.groupBox_17 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_17.setObjectName("groupBox_17")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.groupBox_17)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.FW = QtWidgets.QCheckBox(self.groupBox_17)
        self.FW.setObjectName("FW")
        self.verticalLayout_16.addWidget(self.FW)
        self.Compost = QtWidgets.QCheckBox(self.groupBox_17)
        self.Compost.setObjectName("Compost")
        self.verticalLayout_16.addWidget(self.Compost)
        self.ADSolids = QtWidgets.QCheckBox(self.groupBox_17)
        self.ADSolids.setObjectName("ADSolids")
        self.verticalLayout_16.addWidget(self.ADSolids)
        self.ADLiquids = QtWidgets.QCheckBox(self.groupBox_17)
        self.ADLiquids.setObjectName("ADLiquids")
        self.verticalLayout_16.addWidget(self.ADLiquids)
        self.verticalLayout_18.addWidget(self.groupBox_17)
        self.groupBox_2 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.CompRes = QtWidgets.QCheckBox(self.groupBox_2)
        self.CompRes.setObjectName("CompRes")
        self.verticalLayout_10.addWidget(self.CompRes)
        self.MRFRes = QtWidgets.QCheckBox(self.groupBox_2)
        self.MRFRes.setObjectName("MRFRes")
        self.verticalLayout_10.addWidget(self.MRFRes)
        self.CombRes = QtWidgets.QCheckBox(self.groupBox_2)
        self.CombRes.setObjectName("CombRes")
        self.verticalLayout_10.addWidget(self.CombRes)
        self.AutoShredRes = QtWidgets.QCheckBox(self.groupBox_2)
        self.AutoShredRes.setObjectName("AutoShredRes")
        self.verticalLayout_10.addWidget(self.AutoShredRes)
        self.verticalLayout_18.addWidget(self.groupBox_2)
        self.gridLayout_6.addLayout(self.verticalLayout_18, 0, 0, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_6.addItem(spacerItem6, 0, 1, 1, 1)
        self.gridLayout_10.addWidget(self.groupBox, 2, 0, 1, 2)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_10.addItem(spacerItem7, 4, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.ProcModel_clear = QtWidgets.QPushButton(self.PM_tab)
        self.ProcModel_clear.setIcon(icon4)
        self.ProcModel_clear.setObjectName("ProcModel_clear")
        self.horizontalLayout_3.addWidget(self.ProcModel_clear)
        self.ProcModel_update = QtWidgets.QPushButton(self.PM_tab)
        self.ProcModel_update.setIcon(icon3)
        self.ProcModel_update.setObjectName("ProcModel_update")
        self.horizontalLayout_3.addWidget(self.ProcModel_update)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem8)
        self.Check_Data = QtWidgets.QPushButton(self.PM_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Check_Data.sizePolicy().hasHeightForWidth())
        self.Check_Data.setSizePolicy(sizePolicy)
        self.Check_Data.setMinimumSize(QtCore.QSize(0, 0))
        self.Check_Data.setIcon(icon1)
        self.Check_Data.setObjectName("Check_Data")
        self.horizontalLayout_3.addWidget(self.Check_Data)
        self.gridLayout_10.addLayout(self.horizontalLayout_3, 3, 0, 1, 2)
        self.PFAS_SAT_1.addTab(self.PM_tab, "")
        self.PM_Input_Tab = QtWidgets.QWidget()
        self.PM_Input_Tab.setObjectName("PM_Input_Tab")
        self.gridLayout_25 = QtWidgets.QGridLayout(self.PM_Input_Tab)
        self.gridLayout_25.setObjectName("gridLayout_25")
        self.groupBox_21 = QtWidgets.QGroupBox(self.PM_Input_Tab)
        self.groupBox_21.setObjectName("groupBox_21")
        self.gridLayout_26 = QtWidgets.QGridLayout(self.groupBox_21)
        self.gridLayout_26.setObjectName("gridLayout_26")
        self.Clear_PM_uncert = QtWidgets.QPushButton(self.groupBox_21)
        self.Clear_PM_uncert.setIcon(icon4)
        self.Clear_PM_uncert.setObjectName("Clear_PM_uncert")
        self.gridLayout_26.addWidget(self.Clear_PM_uncert, 2, 0, 1, 1)
        self.PM_InputData_Table = QtWidgets.QTableView(self.groupBox_21)
        self.PM_InputData_Table.setMinimumSize(QtCore.QSize(0, 400))
        self.PM_InputData_Table.setObjectName("PM_InputData_Table")
        self.gridLayout_26.addWidget(self.PM_InputData_Table, 1, 0, 1, 5)
        spacerItem9 = QtWidgets.QSpacerItem(483, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_26.addItem(spacerItem9, 2, 3, 1, 1)
        self.Update_PM_Data = QtWidgets.QPushButton(self.groupBox_21)
        self.Update_PM_Data.setIcon(icon3)
        self.Update_PM_Data.setObjectName("Update_PM_Data")
        self.gridLayout_26.addWidget(self.Update_PM_Data, 2, 1, 1, 1)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_11 = QtWidgets.QLabel(self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_11.sizePolicy().hasHeightForWidth())
        self.label_11.setSizePolicy(sizePolicy)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_6.addWidget(self.label_11)
        self.PM_Input_model = QtWidgets.QComboBox(self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PM_Input_model.sizePolicy().hasHeightForWidth())
        self.PM_Input_model.setSizePolicy(sizePolicy)
        self.PM_Input_model.setMinimumSize(QtCore.QSize(300, 0))
        self.PM_Input_model.setObjectName("PM_Input_model")
        self.horizontalLayout_6.addWidget(self.PM_Input_model)
        self.PM_Input_Help = QtWidgets.QPushButton(self.groupBox_21)
        self.PM_Input_Help.setText("")
        self.PM_Input_Help.setIcon(icon5)
        self.PM_Input_Help.setIconSize(QtCore.QSize(24, 24))
        self.PM_Input_Help.setObjectName("PM_Input_Help")
        self.horizontalLayout_6.addWidget(self.PM_Input_Help)
        self.PM_Show_Uncertainty = QtWidgets.QCheckBox(self.groupBox_21)
        self.PM_Show_Uncertainty.setObjectName("PM_Show_Uncertainty")
        self.horizontalLayout_6.addWidget(self.PM_Show_Uncertainty)
        self.PM_UncertaintyHelp = QtWidgets.QPushButton(self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PM_UncertaintyHelp.sizePolicy().hasHeightForWidth())
        self.PM_UncertaintyHelp.setSizePolicy(sizePolicy)
        self.PM_UncertaintyHelp.setIcon(icon5)
        self.PM_UncertaintyHelp.setIconSize(QtCore.QSize(24, 24))
        self.PM_UncertaintyHelp.setObjectName("PM_UncertaintyHelp")
        self.horizontalLayout_6.addWidget(self.PM_UncertaintyHelp)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem10)
        self.gridLayout_26.addLayout(self.horizontalLayout_6, 0, 0, 1, 5)
        self.Def_System = QtWidgets.QPushButton(self.groupBox_21)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Def_System.sizePolicy().hasHeightForWidth())
        self.Def_System.setSizePolicy(sizePolicy)
        self.Def_System.setMinimumSize(QtCore.QSize(0, 0))
        self.Def_System.setIcon(icon1)
        self.Def_System.setObjectName("Def_System")
        self.gridLayout_26.addWidget(self.Def_System, 2, 4, 1, 1)
        self.PM_ExportData = QtWidgets.QPushButton(self.groupBox_21)
        self.PM_ExportData.setIcon(icon6)
        self.PM_ExportData.setObjectName("PM_ExportData")
        self.gridLayout_26.addWidget(self.PM_ExportData, 2, 2, 1, 1)
        self.gridLayout_25.addWidget(self.groupBox_21, 0, 0, 1, 1)
        self.PFAS_SAT_1.addTab(self.PM_Input_Tab, "")
        self.SYS_tab = QtWidgets.QWidget()
        self.SYS_tab.setObjectName("SYS_tab")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.SYS_tab)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.groupBox_20 = QtWidgets.QGroupBox(self.SYS_tab)
        self.groupBox_20.setObjectName("groupBox_20")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.groupBox_20)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.FU_Label = QtWidgets.QLabel(self.groupBox_20)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.FU_Label.setFont(font)
        self.FU_Label.setObjectName("FU_Label")
        self.horizontalLayout_15.addWidget(self.FU_Label)
        self.FU = QtWidgets.QComboBox(self.groupBox_20)
        self.FU.setMinimumSize(QtCore.QSize(200, 0))
        self.FU.setObjectName("FU")
        self.horizontalLayout_15.addWidget(self.FU)
        self.FU_amount = QtWidgets.QLineEdit(self.groupBox_20)
        self.FU_amount.setObjectName("FU_amount")
        self.horizontalLayout_15.addWidget(self.FU_amount)
        self.FU_unit = QtWidgets.QLabel(self.groupBox_20)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.FU_unit.setFont(font)
        self.FU_unit.setObjectName("FU_unit")
        self.horizontalLayout_15.addWidget(self.FU_unit)
        self.InitProject_Buttom = QtWidgets.QPushButton(self.groupBox_20)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/ICONS/run.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.InitProject_Buttom.setIcon(icon7)
        self.InitProject_Buttom.setObjectName("InitProject_Buttom")
        self.horizontalLayout_15.addWidget(self.InitProject_Buttom)
        self.reset = QtWidgets.QPushButton(self.groupBox_20)
        self.reset.setIcon(icon4)
        self.reset.setObjectName("reset")
        self.horizontalLayout_15.addWidget(self.reset)
        spacerItem11 = QtWidgets.QSpacerItem(345, 14, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_15.addItem(spacerItem11)
        self.gridLayout_9.addWidget(self.groupBox_20, 0, 0, 1, 1)
        self.splitter = QtWidgets.QSplitter(self.SYS_tab)
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setObjectName("splitter")
        self.frame_5 = QtWidgets.QFrame(self.splitter)
        self.frame_5.setMinimumSize(QtCore.QSize(1000, 0))
        self.frame_5.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_5.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_5.setObjectName("frame_5")
        self.gridLayout_13 = QtWidgets.QGridLayout(self.frame_5)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.splitter_5 = QtWidgets.QSplitter(self.frame_5)
        self.splitter_5.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_5.setObjectName("splitter_5")
        self.FU_Proc_Widget = QtWidgets.QGroupBox(self.splitter_5)
        self.FU_Proc_Widget.setMinimumSize(QtCore.QSize(400, 200))
        self.FU_Proc_Widget.setObjectName("FU_Proc_Widget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.FU_Proc_Widget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.ProcessSetFrame = QtWidgets.QFrame(self.FU_Proc_Widget)
        self.ProcessSetFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.ProcessSetFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.ProcessSetFrame.setObjectName("ProcessSetFrame")
        self.verticalLayout_2.addWidget(self.ProcessSetFrame)
        self.Set_ProcessSet = QtWidgets.QPushButton(self.FU_Proc_Widget)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/ICONS/Create.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.Set_ProcessSet.setIcon(icon8)
        self.Set_ProcessSet.setObjectName("Set_ProcessSet")
        self.verticalLayout_2.addWidget(self.Set_ProcessSet)
        self.FU_Param_Widget = QtWidgets.QGroupBox(self.splitter_5)
        self.FU_Param_Widget.setMinimumSize(QtCore.QSize(400, 200))
        self.FU_Param_Widget.setObjectName("FU_Param_Widget")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.FU_Param_Widget)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.FlowParams_TreeView = QtWidgets.QTreeView(self.FU_Param_Widget)
        self.FlowParams_TreeView.setObjectName("FlowParams_TreeView")
        self.gridLayout_4.addWidget(self.FlowParams_TreeView, 0, 0, 1, 2)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.Update_Flowparams = QtWidgets.QPushButton(self.FU_Param_Widget)
        self.Update_Flowparams.setIcon(icon3)
        self.Update_Flowparams.setObjectName("Update_Flowparams")
        self.horizontalLayout_2.addWidget(self.Update_Flowparams)
        self.FA_Btm = QtWidgets.QPushButton(self.FU_Param_Widget)
        self.FA_Btm.setIcon(icon1)
        self.FA_Btm.setObjectName("FA_Btm")
        self.horizontalLayout_2.addWidget(self.FA_Btm)
        self.MC_Btm = QtWidgets.QPushButton(self.FU_Param_Widget)
        self.MC_Btm.setIcon(icon1)
        self.MC_Btm.setObjectName("MC_Btm")
        self.horizontalLayout_2.addWidget(self.MC_Btm)
        self.SA_Btm = QtWidgets.QPushButton(self.FU_Param_Widget)
        self.SA_Btm.setIcon(icon1)
        self.SA_Btm.setObjectName("SA_Btm")
        self.horizontalLayout_2.addWidget(self.SA_Btm)
        self.gridLayout_4.addLayout(self.horizontalLayout_2, 1, 0, 1, 2)
        self.gridLayout_13.addWidget(self.splitter_5, 0, 0, 1, 1)
        self.frame_8 = QtWidgets.QFrame(self.splitter)
        self.frame_8.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_8.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_8.setObjectName("frame_8")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.frame_8)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.FU_Network = QtWidgets.QGroupBox(self.frame_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FU_Network.sizePolicy().hasHeightForWidth())
        self.FU_Network.setSizePolicy(sizePolicy)
        self.FU_Network.setMinimumSize(QtCore.QSize(600, 300))
        self.FU_Network.setObjectName("FU_Network")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.FU_Network)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.scrollArea = QtWidgets.QScrollArea(self.FU_Network)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 98, 31))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.scrollAreaWidgetContents)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.Network_ImageLable = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        self.Network_ImageLable.setText("")
        self.Network_ImageLable.setScaledContents(False)
        self.Network_ImageLable.setObjectName("Network_ImageLable")
        self.gridLayout_3.addWidget(self.Network_ImageLable, 0, 0, 1, 1)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.gridLayout_16.addWidget(self.scrollArea, 0, 0, 1, 1)
        self.gridLayout_12.addWidget(self.FU_Network, 0, 0, 1, 1)
        self.gridLayout_9.addWidget(self.splitter, 1, 0, 1, 1)
        self.PFAS_SAT_1.addTab(self.SYS_tab, "")
        self.FA_tab = QtWidgets.QWidget()
        self.FA_tab.setObjectName("FA_tab")
        self.gridLayout_14 = QtWidgets.QGridLayout(self.FA_tab)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.splitter_2 = QtWidgets.QSplitter(self.FA_tab)
        self.splitter_2.setOrientation(QtCore.Qt.Vertical)
        self.splitter_2.setObjectName("splitter_2")
        self.groupBox_6 = QtWidgets.QGroupBox(self.splitter_2)
        self.groupBox_6.setObjectName("groupBox_6")
        self.gridLayout_20 = QtWidgets.QGridLayout(self.groupBox_6)
        self.gridLayout_20.setObjectName("gridLayout_20")
        self.Inventory_table = QtWidgets.QTableView(self.groupBox_6)
        self.Inventory_table.setObjectName("Inventory_table")
        self.gridLayout_20.addWidget(self.Inventory_table, 0, 0, 1, 1)
        self.Sankey_groupBox = QtWidgets.QGroupBox(self.splitter_2)
        self.Sankey_groupBox.setMinimumSize(QtCore.QSize(0, 400))
        self.Sankey_groupBox.setObjectName("Sankey_groupBox")
        self.gridLayout_15 = QtWidgets.QGridLayout(self.Sankey_groupBox)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.Sankey_layout = QtWidgets.QVBoxLayout()
        self.Sankey_layout.setObjectName("Sankey_layout")
        self.gridLayout_15.addLayout(self.Sankey_layout, 0, 0, 1, 1)
        self.gridLayout_14.addWidget(self.splitter_2, 0, 0, 1, 1)
        self.PFAS_SAT_1.addTab(self.FA_tab, "")
        self.MC_tab = QtWidgets.QWidget()
        self.MC_tab.setObjectName("MC_tab")
        self.gridLayout_88 = QtWidgets.QGridLayout(self.MC_tab)
        self.gridLayout_88.setObjectName("gridLayout_88")
        self.frame_2 = QtWidgets.QFrame(self.MC_tab)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.gridLayout_18 = QtWidgets.QGridLayout(self.frame_2)
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.groupBox_13 = QtWidgets.QGroupBox(self.frame_2)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.groupBox_13.setFont(font)
        self.groupBox_13.setObjectName("groupBox_13")
        self.gridLayout_19 = QtWidgets.QGridLayout(self.groupBox_13)
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.frame_3 = QtWidgets.QFrame(self.groupBox_13)
        self.frame_3.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.gridLayout_17 = QtWidgets.QGridLayout(self.frame_3)
        self.gridLayout_17.setObjectName("gridLayout_17")
        spacerItem12 = QtWidgets.QSpacerItem(95, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_17.addItem(spacerItem12, 0, 4, 1, 1)
        self.MC_uncertain_filter = QtWidgets.QCheckBox(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_uncertain_filter.sizePolicy().hasHeightForWidth())
        self.MC_uncertain_filter.setSizePolicy(sizePolicy)
        self.MC_uncertain_filter.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_uncertain_filter.setFont(font)
        self.MC_uncertain_filter.setObjectName("MC_uncertain_filter")
        self.gridLayout_17.addWidget(self.MC_uncertain_filter, 0, 2, 1, 1)
        self.MC_uncertain_update = QtWidgets.QPushButton(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_uncertain_update.sizePolicy().hasHeightForWidth())
        self.MC_uncertain_update.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_uncertain_update.setFont(font)
        self.MC_uncertain_update.setIcon(icon3)
        self.MC_uncertain_update.setObjectName("MC_uncertain_update")
        self.gridLayout_17.addWidget(self.MC_uncertain_update, 0, 6, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_5.sizePolicy().hasHeightForWidth())
        self.label_5.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridLayout_17.addWidget(self.label_5, 0, 0, 1, 1)
        self.MC_unceratin_clear = QtWidgets.QPushButton(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_unceratin_clear.sizePolicy().hasHeightForWidth())
        self.MC_unceratin_clear.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_unceratin_clear.setFont(font)
        self.MC_unceratin_clear.setIcon(icon4)
        self.MC_unceratin_clear.setObjectName("MC_unceratin_clear")
        self.gridLayout_17.addWidget(self.MC_unceratin_clear, 0, 5, 1, 1)
        self.MC_UncertaintyHelp = QtWidgets.QPushButton(self.frame_3)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_UncertaintyHelp.setFont(font)
        self.MC_UncertaintyHelp.setIcon(icon5)
        self.MC_UncertaintyHelp.setIconSize(QtCore.QSize(24, 24))
        self.MC_UncertaintyHelp.setObjectName("MC_UncertaintyHelp")
        self.gridLayout_17.addWidget(self.MC_UncertaintyHelp, 0, 3, 1, 1)
        self.MC_Model = QtWidgets.QComboBox(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_Model.sizePolicy().hasHeightForWidth())
        self.MC_Model.setSizePolicy(sizePolicy)
        self.MC_Model.setMinimumSize(QtCore.QSize(200, 0))
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_Model.setFont(font)
        self.MC_Model.setObjectName("MC_Model")
        self.gridLayout_17.addWidget(self.MC_Model, 0, 1, 1, 1)
        self.MC_ExportData = QtWidgets.QPushButton(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_ExportData.sizePolicy().hasHeightForWidth())
        self.MC_ExportData.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_ExportData.setFont(font)
        self.MC_ExportData.setIcon(icon6)
        self.MC_ExportData.setObjectName("MC_ExportData")
        self.gridLayout_17.addWidget(self.MC_ExportData, 0, 7, 1, 1)
        self.gridLayout_19.addWidget(self.frame_3, 0, 0, 1, 1)
        self.MC_Uncertain_table = QtWidgets.QTableView(self.groupBox_13)
        self.MC_Uncertain_table.setMinimumSize(QtCore.QSize(0, 200))
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_Uncertain_table.setFont(font)
        self.MC_Uncertain_table.setObjectName("MC_Uncertain_table")
        self.gridLayout_19.addWidget(self.MC_Uncertain_table, 1, 0, 1, 1)
        self.gridLayout_18.addWidget(self.groupBox_13, 0, 0, 1, 1)
        self.groupBox_14 = QtWidgets.QGroupBox(self.frame_2)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.groupBox_14.setFont(font)
        self.groupBox_14.setObjectName("groupBox_14")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_14)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.MC_run = QtWidgets.QPushButton(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_run.sizePolicy().hasHeightForWidth())
        self.MC_run.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_run.setFont(font)
        self.MC_run.setIcon(icon7)
        self.MC_run.setObjectName("MC_run")
        self.gridLayout_5.addWidget(self.MC_run, 0, 8, 1, 1)
        self.MC_show = QtWidgets.QPushButton(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_show.sizePolicy().hasHeightForWidth())
        self.MC_show.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_show.setFont(font)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/ICONS/show.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.MC_show.setIcon(icon9)
        self.MC_show.setObjectName("MC_show")
        self.gridLayout_5.addWidget(self.MC_show, 0, 11, 1, 1)
        self.MC_save = QtWidgets.QPushButton(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_save.sizePolicy().hasHeightForWidth())
        self.MC_save.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_save.setFont(font)
        self.MC_save.setIcon(icon6)
        self.MC_save.setObjectName("MC_save")
        self.gridLayout_5.addWidget(self.MC_save, 0, 12, 1, 1)
        self.label_68 = QtWidgets.QLabel(self.groupBox_14)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.label_68.setFont(font)
        self.label_68.setObjectName("label_68")
        self.gridLayout_5.addWidget(self.label_68, 0, 0, 1, 1)
        self.MC_PBr = QtWidgets.QProgressBar(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_PBr.sizePolicy().hasHeightForWidth())
        self.MC_PBr.setSizePolicy(sizePolicy)
        self.MC_PBr.setMaximumSize(QtCore.QSize(300, 16777215))
        self.MC_PBr.setProperty("value", 0)
        self.MC_PBr.setTextVisible(False)
        self.MC_PBr.setObjectName("MC_PBr")
        self.gridLayout_5.addWidget(self.MC_PBr, 0, 9, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_14)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.label_12.setFont(font)
        self.label_12.setObjectName("label_12")
        self.gridLayout_5.addWidget(self.label_12, 0, 4, 1, 1)
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem13, 0, 10, 1, 1)
        self.MC_PFAS = QtWidgets.QComboBox(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_PFAS.sizePolicy().hasHeightForWidth())
        self.MC_PFAS.setSizePolicy(sizePolicy)
        self.MC_PFAS.setMinimumSize(QtCore.QSize(200, 0))
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_PFAS.setFont(font)
        self.MC_PFAS.setObjectName("MC_PFAS")
        self.gridLayout_5.addWidget(self.MC_PFAS, 0, 5, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.groupBox_14)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.label_13.setFont(font)
        self.label_13.setObjectName("label_13")
        self.gridLayout_5.addWidget(self.label_13, 0, 2, 1, 1)
        self.MC_N_runs = QtWidgets.QSpinBox(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_N_runs.sizePolicy().hasHeightForWidth())
        self.MC_N_runs.setSizePolicy(sizePolicy)
        self.MC_N_runs.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_N_runs.setFont(font)
        self.MC_N_runs.setObjectName("MC_N_runs")
        self.gridLayout_5.addWidget(self.MC_N_runs, 0, 1, 1, 1)
        self.MC_Seed = QtWidgets.QSpinBox(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MC_Seed.sizePolicy().hasHeightForWidth())
        self.MC_Seed.setSizePolicy(sizePolicy)
        self.MC_Seed.setMinimumSize(QtCore.QSize(70, 0))
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.MC_Seed.setFont(font)
        self.MC_Seed.setObjectName("MC_Seed")
        self.gridLayout_5.addWidget(self.MC_Seed, 0, 3, 1, 1)
        self.gridLayout_18.addWidget(self.groupBox_14, 1, 0, 1, 1)
        self.gridLayout_88.addWidget(self.frame_2, 0, 0, 1, 1)
        self.PFAS_SAT_1.addTab(self.MC_tab, "")
        self.SA_tab = QtWidgets.QWidget()
        self.SA_tab.setObjectName("SA_tab")
        self.gridLayout_28 = QtWidgets.QGridLayout(self.SA_tab)
        self.gridLayout_28.setObjectName("gridLayout_28")
        self.splitter_3 = QtWidgets.QSplitter(self.SA_tab)
        self.splitter_3.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_3.setObjectName("splitter_3")
        self.groupBox_7 = QtWidgets.QGroupBox(self.splitter_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_7.sizePolicy().hasHeightForWidth())
        self.groupBox_7.setSizePolicy(sizePolicy)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_22 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_22.setObjectName("gridLayout_22")
        self.label_3 = QtWidgets.QLabel(self.groupBox_7)
        self.label_3.setObjectName("label_3")
        self.gridLayout_22.addWidget(self.label_3, 0, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_7)
        self.label_6.setObjectName("label_6")
        self.gridLayout_22.addWidget(self.label_6, 2, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_7)
        self.label_4.setObjectName("label_4")
        self.gridLayout_22.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.groupBox_7)
        self.label_8.setObjectName("label_8")
        self.gridLayout_22.addWidget(self.label_8, 3, 0, 1, 1)
        self.SA_Start = QtWidgets.QLineEdit(self.groupBox_7)
        self.SA_Start.setObjectName("SA_Start")
        self.gridLayout_22.addWidget(self.SA_Start, 3, 1, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.groupBox_7)
        self.label_9.setObjectName("label_9")
        self.gridLayout_22.addWidget(self.label_9, 4, 0, 1, 1)
        self.SA_Unit_1 = QtWidgets.QLabel(self.groupBox_7)
        self.SA_Unit_1.setMinimumSize(QtCore.QSize(100, 0))
        self.SA_Unit_1.setText("")
        self.SA_Unit_1.setObjectName("SA_Unit_1")
        self.gridLayout_22.addWidget(self.SA_Unit_1, 3, 2, 1, 1)
        spacerItem14 = QtWidgets.QSpacerItem(555, 84, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_22.addItem(spacerItem14, 3, 3, 3, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_7)
        self.label_10.setObjectName("label_10")
        self.gridLayout_22.addWidget(self.label_10, 5, 0, 1, 1)
        self.SA_Stop = QtWidgets.QLineEdit(self.groupBox_7)
        self.SA_Stop.setObjectName("SA_Stop")
        self.gridLayout_22.addWidget(self.SA_Stop, 4, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox_7)
        self.label_7.setObjectName("label_7")
        self.gridLayout_22.addWidget(self.label_7, 6, 0, 1, 1)
        self.SA_Unit_2 = QtWidgets.QLabel(self.groupBox_7)
        self.SA_Unit_2.setText("")
        self.SA_Unit_2.setObjectName("SA_Unit_2")
        self.gridLayout_22.addWidget(self.SA_Unit_2, 4, 2, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.SA_Run = QtWidgets.QPushButton(self.groupBox_7)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.SA_Run.setFont(font)
        self.SA_Run.setIcon(icon7)
        self.SA_Run.setObjectName("SA_Run")
        self.horizontalLayout.addWidget(self.SA_Run)
        self.SA_Plot = QtWidgets.QPushButton(self.groupBox_7)
        self.SA_Plot.setIcon(icon9)
        self.SA_Plot.setObjectName("SA_Plot")
        self.horizontalLayout.addWidget(self.SA_Plot)
        self.SA_Save = QtWidgets.QPushButton(self.groupBox_7)
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(False)
        self.SA_Save.setFont(font)
        self.SA_Save.setIcon(icon6)
        self.SA_Save.setObjectName("SA_Save")
        self.horizontalLayout.addWidget(self.SA_Save)
        self.SA_Clear = QtWidgets.QPushButton(self.groupBox_7)
        self.SA_Clear.setIcon(icon4)
        self.SA_Clear.setObjectName("SA_Clear")
        self.horizontalLayout.addWidget(self.SA_Clear)
        self.gridLayout_22.addLayout(self.horizontalLayout, 7, 0, 1, 4)
        self.SA_PFAS = QtWidgets.QComboBox(self.groupBox_7)
        self.SA_PFAS.setObjectName("SA_PFAS")
        self.gridLayout_22.addWidget(self.SA_PFAS, 6, 1, 1, 1)
        self.SA_Category = QtWidgets.QComboBox(self.groupBox_7)
        self.SA_Category.setObjectName("SA_Category")
        self.gridLayout_22.addWidget(self.SA_Category, 1, 1, 1, 3)
        self.SA_Parameter = QtWidgets.QComboBox(self.groupBox_7)
        self.SA_Parameter.setObjectName("SA_Parameter")
        self.gridLayout_22.addWidget(self.SA_Parameter, 2, 1, 1, 3)
        self.SA_Model = QtWidgets.QComboBox(self.groupBox_7)
        self.SA_Model.setObjectName("SA_Model")
        self.gridLayout_22.addWidget(self.SA_Model, 0, 1, 1, 3)
        self.SA_NStep = QtWidgets.QSpinBox(self.groupBox_7)
        self.SA_NStep.setObjectName("SA_NStep")
        self.gridLayout_22.addWidget(self.SA_NStep, 5, 1, 1, 1)
        self.groupBox_10 = QtWidgets.QGroupBox(self.splitter_3)
        self.groupBox_10.setMinimumSize(QtCore.QSize(300, 0))
        self.groupBox_10.setObjectName("groupBox_10")
        self.gridLayout_23 = QtWidgets.QGridLayout(self.groupBox_10)
        self.gridLayout_23.setObjectName("gridLayout_23")
        self.SA_ParamInfo = QtWidgets.QTextBrowser(self.groupBox_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SA_ParamInfo.sizePolicy().hasHeightForWidth())
        self.SA_ParamInfo.setSizePolicy(sizePolicy)
        self.SA_ParamInfo.setObjectName("SA_ParamInfo")
        self.gridLayout_23.addWidget(self.SA_ParamInfo, 0, 0, 1, 1)
        self.gridLayout_28.addWidget(self.splitter_3, 0, 0, 1, 1)
        self.groupBox_9 = QtWidgets.QGroupBox(self.SA_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_9.sizePolicy().hasHeightForWidth())
        self.groupBox_9.setSizePolicy(sizePolicy)
        self.groupBox_9.setMinimumSize(QtCore.QSize(0, 500))
        self.groupBox_9.setObjectName("groupBox_9")
        self.gridLayout_21 = QtWidgets.QGridLayout(self.groupBox_9)
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.SA_Results = QtWidgets.QTableView(self.groupBox_9)
        self.SA_Results.setObjectName("SA_Results")
        self.gridLayout_21.addWidget(self.SA_Results, 0, 0, 1, 1)
        self.gridLayout_28.addWidget(self.groupBox_9, 1, 0, 1, 1)
        self.PFAS_SAT_1.addTab(self.SA_tab, "")
        self.gridLayout_11.addWidget(self.PFAS_SAT_1, 0, 0, 1, 1)
        PFAS_SAT.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(PFAS_SAT)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1200, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuReferences = QtWidgets.QMenu(self.menubar)
        self.menuReferences.setObjectName("menuReferences")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        PFAS_SAT.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(PFAS_SAT)
        self.statusbar.setObjectName("statusbar")
        PFAS_SAT.setStatusBar(self.statusbar)
        self.actionExit = QtWidgets.QAction(PFAS_SAT)
        self.actionExit.setObjectName("actionExit")
        self.actionSaveInventory = QtWidgets.QAction(PFAS_SAT)
        self.actionSaveInventory.setIcon(icon6)
        self.actionSaveInventory.setObjectName("actionSaveInventory")
        self.actionHelp_Gui = QtWidgets.QAction(PFAS_SAT)
        self.actionHelp_Gui.setIcon(icon5)
        self.actionHelp_Gui.setObjectName("actionHelp_Gui")
        self.actionFAQ = QtWidgets.QAction(PFAS_SAT)
        self.actionFAQ.setObjectName("actionFAQ")
        self.actionAbout_PFAS_SAT = QtWidgets.QAction(PFAS_SAT)
        self.actionAbout_PFAS_SAT.setObjectName("actionAbout_PFAS_SAT")
        self.actionReferences = QtWidgets.QAction(PFAS_SAT)
        self.actionReferences.setObjectName("actionReferences")
        self.actionOptions = QtWidgets.QAction(PFAS_SAT)
        self.actionOptions.setIcon(icon8)
        self.actionOptions.setObjectName("actionOptions")
        self.menuFile.addAction(self.actionSaveInventory)
        self.menuFile.addAction(self.actionExit)
        self.menuHelp.addAction(self.actionHelp_Gui)
        self.menuReferences.addAction(self.actionReferences)
        self.menuTools.addAction(self.actionOptions)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.menubar.addAction(self.menuReferences.menuAction())

        self.retranslateUi(PFAS_SAT)
        self.PFAS_SAT_1.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(PFAS_SAT)

    def retranslateUi(self, PFAS_SAT):
        PFAS_SAT.setWindowTitle(QtWidgets.QApplication.translate("PFAS_SAT", "PFAS SAT", None, -1))
        self.Start_new_project.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Start New Project", None, -1))
        self.textBrowser.setHtml(QtWidgets.QApplication.translate("PFAS_SAT", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'MS Shell Dlg 2\'; font-size:20pt; font-weight:600; color:#aa0000;\">PFAS SAT</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'MS Shell Dlg 2\'; font-size:16pt; color:#aa0000;\">Developed at North Carolina State University</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\":/icons/ICONS/PFAS_SAT.png\" /></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'MS Shell Dlg 2\'; font-size:10pt; font-weight:600; color:#aa0000;\">Development Team:</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; font-weight:600; color:#000000;\">Mojtaba Sardarmehni</span><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; color:#000000;\">, PhD</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; font-weight:600; color:#000000;\">Yuemei Ye</span><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; color:#000000;\">, PhD </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; font-weight:600; color:#000000;\">Dr. James W. Levis</span><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; color:#000000;\">, Research Assistant Professor</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; font-weight:600; color:#000000;\">Dr. Detlef Knappe</span><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; color:#000000;\">, S. James Ellen Distinguished Professor</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; font-weight:600; color:#000000;\">Dr. Morton Barlaz</span><span style=\" font-family:\'Georgia,serif\'; font-size:8pt; color:#000000;\">, Distinguished Univ. Prof. and Dept. Head</span></p>\n", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.Start_tab), QtWidgets.QApplication.translate("PFAS_SAT", "Start", None, -1))
        self.groupBox_11.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Waste Material Properties File", None, -1))
        self.WM_DefData.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Default", None, -1))
        self.WM_UserData.setText(QtWidgets.QApplication.translate("PFAS_SAT", "User Defined", None, -1))
        self.WM_browse.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Browse", None, -1))
        self.WM_ImportData.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Import", None, -1))
        self.groupBox_18.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Waste Material Properties", None, -1))
        self.Def_Proc_models.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Define Process Models", None, -1))
        self.Update_WM_prop.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Update", None, -1))
        self.Clear_WM_uncert.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Clear Uncertainty", None, -1))
        self.label_2.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Waste Materials:", None, -1))
        self.WM_Show_Uncertainty.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Show uncertainty distributions", None, -1))
        self.WM_UncertaintyHelp.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Uncertainty Distributions Help", None, -1))
        self.WM_ExportData.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Export Data", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.WM_tab), QtWidgets.QApplication.translate("PFAS_SAT", "Waste Materials Properties", None, -1))
        self.label.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Process:", None, -1))
        self.groupBox_19.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Process Model Input File", None, -1))
        self.ProcModel_def_input.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Default", None, -1))
        self.ProcModel_user_input.setText(QtWidgets.QApplication.translate("PFAS_SAT", "User Defined", None, -1))
        self.ProcModel_Brow_Input.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Browse", None, -1))
        self.groupBox.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Input Flow Types", None, -1))
        self.groupBox_3.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Contaminated", None, -1))
        self.ContWater.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Contaminated Water", None, -1))
        self.ContSoil.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Contaminated Soil", None, -1))
        self.groupBox_5.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Water Treatment", None, -1))
        self.ContactWater.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Contact Water", None, -1))
        self.LFLeach.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Landfill Leachate", None, -1))
        self.WWTEffluent.setText(QtWidgets.QApplication.translate("PFAS_SAT", "WWT Effluent", None, -1))
        self.WWTSol.setText(QtWidgets.QApplication.translate("PFAS_SAT", "WWT Screen Rejects", None, -1))
        self.RawWWTSol.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Raw WWT Solids", None, -1))
        self.DewWWTSol.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Dewatered WWT Solids", None, -1))
        self.DryWWTSol.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Dried WWT Solids", None, -1))
        self.ROC.setText(QtWidgets.QApplication.translate("PFAS_SAT", "RO Concentrate", None, -1))
        self.SGAC.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Spent Granular Activated Carbon", None, -1))
        self.SIER.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Spent Ion Exchange Resin", None, -1))
        self.groupBox_15.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Other", None, -1))
        self.StabSoil.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Stabilized Soil", None, -1))
        self.Solidi_Waste.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Solidified Waste", None, -1))
        self.AFFF_1.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Aqueous Film-Forming Foam (Sulfonate-based)", None, -1))
        self.AFFF_2.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Aqueous Film-Forming Foam (Fluorotelomer-based)", None, -1))
        self.groupBox_4.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Solid Waste", None, -1))
        self.MSW.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Municipal Solid Waste", None, -1))
        self.C_D_Waste.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Construction and Demolition Waste", None, -1))
        self.Med_Waste.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Medical Waste", None, -1))
        self.MOSP.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Miscellaneous Off-Spec Products", None, -1))
        self.groupBox_17.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Compost", None, -1))
        self.FW.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Food Waste", None, -1))
        self.Compost.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Compost", None, -1))
        self.ADSolids.setText(QtWidgets.QApplication.translate("PFAS_SAT", "AD Solids", None, -1))
        self.ADLiquids.setText(QtWidgets.QApplication.translate("PFAS_SAT", "AD Liquids", None, -1))
        self.groupBox_2.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Residuals", None, -1))
        self.CompRes.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Compost Residuals", None, -1))
        self.MRFRes.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Material Recovery Facility Residuals", None, -1))
        self.CombRes.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Combustion Residuals", None, -1))
        self.AutoShredRes.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Automobile Shredder Residuals", None, -1))
        self.ProcModel_clear.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Clear", None, -1))
        self.ProcModel_update.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Update", None, -1))
        self.Check_Data.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Check Process Models Input Data", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.PM_tab), QtWidgets.QApplication.translate("PFAS_SAT", "Process Models", None, -1))
        self.groupBox_21.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Process Model Input Data", None, -1))
        self.Clear_PM_uncert.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Clear Uncertainty", None, -1))
        self.Update_PM_Data.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Update", None, -1))
        self.label_11.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Process:", None, -1))
        self.PM_Show_Uncertainty.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Show uncertainty distributions", None, -1))
        self.PM_UncertaintyHelp.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Uncertainty distributions help", None, -1))
        self.Def_System.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Define System", None, -1))
        self.PM_ExportData.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Export Data", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.PM_Input_Tab), QtWidgets.QApplication.translate("PFAS_SAT", "Process Models Input Data", None, -1))
        self.groupBox_20.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Starting Material", None, -1))
        self.FU_Label.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Waste Material", None, -1))
        self.FU_unit.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Unit", None, -1))
        self.InitProject_Buttom.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Setup scenario", None, -1))
        self.reset.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Reset", None, -1))
        self.FU_Proc_Widget.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Treatment Processes", None, -1))
        self.Set_ProcessSet.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Create Network", None, -1))
        self.FU_Param_Widget.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Treatment Network Parameters", None, -1))
        self.Update_Flowparams.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Update Network", None, -1))
        self.FA_Btm.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Flow Analysis", None, -1))
        self.MC_Btm.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Monte Carlo", None, -1))
        self.SA_Btm.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Sensitivity Analysis", None, -1))
        self.FU_Network.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Treatment Network", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.SYS_tab), QtWidgets.QApplication.translate("PFAS_SAT", "Define System", None, -1))
        self.groupBox_6.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Results", None, -1))
        self.Sankey_groupBox.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Sankey Diagram", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.FA_tab), QtWidgets.QApplication.translate("PFAS_SAT", "Flow Analysis", None, -1))
        self.groupBox_13.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Uncertainty Browser", None, -1))
        self.MC_uncertain_filter.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Only show input variables with defined uncertainty", None, -1))
        self.MC_uncertain_update.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Update", None, -1))
        self.label_5.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Process Model", None, -1))
        self.MC_unceratin_clear.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Clear", None, -1))
        self.MC_UncertaintyHelp.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Uncertainty Distributions Help", None, -1))
        self.MC_ExportData.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Export Data", None, -1))
        self.groupBox_14.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Run", None, -1))
        self.MC_run.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Run", None, -1))
        self.MC_show.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Show Results", None, -1))
        self.MC_save.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Save results", None, -1))
        self.label_68.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Nnmber of runs:", None, -1))
        self.label_12.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Type of PFAS:", None, -1))
        self.label_13.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Seed:", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.MC_tab), QtWidgets.QApplication.translate("PFAS_SAT", "Monte Carlo simulation", None, -1))
        self.groupBox_7.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Parameter", None, -1))
        self.label_3.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Model:", None, -1))
        self.label_6.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Parameter:", None, -1))
        self.label_4.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Category:", None, -1))
        self.label_8.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Min:", None, -1))
        self.label_9.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Max:", None, -1))
        self.label_10.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Number of steps:", None, -1))
        self.label_7.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Type of PFAS", None, -1))
        self.SA_Run.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Run", None, -1))
        self.SA_Plot.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Plot Results", None, -1))
        self.SA_Save.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Save results", None, -1))
        self.SA_Clear.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Clear", None, -1))
        self.groupBox_10.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Parameter Information", None, -1))
        self.SA_ParamInfo.setHtml(QtWidgets.QApplication.translate("PFAS_SAT", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'MS Shell Dlg 2\'; font-size:8pt;\"><br /></p></body></html>", None, -1))
        self.groupBox_9.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Results", None, -1))
        self.PFAS_SAT_1.setTabText(self.PFAS_SAT_1.indexOf(self.SA_tab), QtWidgets.QApplication.translate("PFAS_SAT", "Sensitivity Analysis", None, -1))
        self.menuFile.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "File", None, -1))
        self.menuHelp.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Help", None, -1))
        self.menuReferences.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "References", None, -1))
        self.menuTools.setTitle(QtWidgets.QApplication.translate("PFAS_SAT", "Tools", None, -1))
        self.actionExit.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Exit", None, -1))
        self.actionSaveInventory.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Save Inventory", None, -1))
        self.actionHelp_Gui.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Help Guides", None, -1))
        self.actionFAQ.setText(QtWidgets.QApplication.translate("PFAS_SAT", "FAQ", None, -1))
        self.actionAbout_PFAS_SAT.setText(QtWidgets.QApplication.translate("PFAS_SAT", "About PFAS_SAT", None, -1))
        self.actionReferences.setText(QtWidgets.QApplication.translate("PFAS_SAT", "References", None, -1))
        self.actionOptions.setText(QtWidgets.QApplication.translate("PFAS_SAT", "Options", None, -1))

from . import PFAS_SAT_rc
